@@ -6,7 +6,7 @@
 mi.scatterplot <- function ( Yobs, Yimp, X = NULL, xlab = NULL, ylab = NULL, 
                             main = "Imputed Variable Scatter Plot", 
                              display.zero = TRUE, gray.scale = FALSE, 
-                              obs.col = rgb( 0, 0, 1, alpha = 0.3 ), 
+                              obs.col = rgb( 0, 0, 1 ), 
                               imp.col = rgb( 1, 0, 0 ), 
                               obs.pch = 20 , imp.pch = 20, 
                               obs.cex = 0.3, imp.cex = 0.3, 
